import { Avatar as MUIAvatar } from "@mui/material";

interface ImageProps {
  src?: string;
  alt?: string;
}

interface TextProps {
  text: string;
}

// Función que convierte el texto en un color basado en un hash del string
function stringToColor(string: string) {
  let hash = 0;
  let i;

  for (i = 0; i < string.length; i += 1) {
    hash = string.charCodeAt(i) + ((hash << 5) - hash);
  }

  let color = "#";

  for (i = 0; i < 3; i += 1) {
    const value = (hash >> (i * 8)) & 0xff;
    color += `00${value.toString(16)}`.slice(-2);
  }

  return color;
}

// Función que convierte el nombre completo en iniciales, por ejemplo "Hazley Jose Jarquin" => "HJ"
function stringAvatar(name: string) {
  const nameParts = name.split(" ");
  let initials = nameParts[0][0]; // Primera letra del primer nombre

  if (nameParts.length > 1) {
    initials += nameParts[nameParts.length - 1][0]; // Primera letra del último apellido
  }

  return {
    sx: {
      bgcolor: stringToColor(name),
    },
    children: initials.toUpperCase(),
  };
}

// eslint-disable-next-line react-refresh/only-export-components
const Image = ({ src, alt }: ImageProps) => <MUIAvatar alt={alt} src={src} />;

// eslint-disable-next-line react-refresh/only-export-components
const Text = ({ text }: TextProps) => (
  <MUIAvatar {...stringAvatar(text ?? "N/A")} />
);

export const Avatar = {
  Image,
  Text,
};
